#!/usr/bin/python

program_name = "batt"
program_version = "0.2"


print "Loading GTK..."

from gtk import *

print "Loading GTK...  done."

def runqueue():
  while events_pending():
    mainiteration()


#
# Config file handling, and defaults...
#

######################################################################
# Config class:
#
def is_config(obj):
  return hasattr(obj,'is_config') and obj.is_config

class config:
  is_config = 1

  def __init__(self):
    import os
    self.options = {}
    self.usrfilename = "%s/.%s.conf" % (os.environ["HOME"], program_name)
    self.globalfilename = "/etc/%s/%s.conf" % (program_name, program_name)
    self.namespace = {
      "options" : self.options,
      }

  ##################################################
  #
  def load(self):
    import os.path
    for name in [self.globalfilename, self.usrfilename]:
      if os.path.exists(name):
        self.parse(name)

  ##################################################
  #
  def parse(self, filename):
    #print "parsing %s..." % filename
    
    try:
      execfile(filename, self.namespace)
    except:
      print "Error in config file %s" % filename
      import traceback, sys
      foo = traceback.format_exception(sys.exc_type,
                                       sys.exc_value,
                                       sys.exc_traceback)
      for item in foo:
        item = item[:-1]
        print item
      print "Press Enter to continue..."
      raw_input()


#
# Battery meter stuff...
#

######################################################################
#
class battwin:

  def __init__(self, cfg):
    self.cfg = cfg
    self.done = 0
    self.ac_on = 0
    self.batt_px = 0.0
    self.apmfile = "/proc/apm"

    self.win = GtkWindow(self.cfg.options["window type"])
    #self.win = GtkWindow()
    self.win.connect("destroy", self.destroy)
    #self.win.set_position(POS_RIGHT|POS_TOP)
    self.win.set_uposition(self.cfg.options["x"],
                           self.cfg.options["y"])
    #self.win.set_transient_for(None)
    #self.win.set_wmclass("batt", WINDOW_TOPLEVEL)
    

    self.hbox = GtkHBox()
    self.win.add(self.hbox)

    if self.cfg.options["ac"]:
      self.ac = GtkLabel("AC")
      self.ac.set_usize(self.cfg.options["ac wid"],
                              self.cfg.options["ac hgt"])
      self.hbox.add(self.ac)

    if self.cfg.options["label"]:
      self.label = GtkLabel()
      self.label.set_text("??.?%")
      self.label.set_usize(self.cfg.options["label wid"],
                           self.cfg.options["label hgt"])
      self.hbox.add(self.label)

    if self.cfg.options["meter"]:
      self.progress = GtkProgressBar()
      self.progress.set_usize(self.cfg.options["meter wid"],
                              self.cfg.options["meter hgt"])
      self.hbox.add(self.progress)

  ##################################################
  #
  def run(self):
    import time

    self.win.show_all()

    while not self.done:
      self.get_info()
      self.update()
      runqueue()
      time.sleep(1)

  ##################################################
  #
  def get_info(self):
    import string

    try:
      fp = open(self.apmfile, "rb")
    except:
      print "Unable to open %s" % self.apmfile

    text = fp.readline()
    fp.close()

    apm = string.split(text, " ")
    self.ac_on = int(apm[3], 16)
    if self.ac_on:
      self.ac_text = "AC"
    else:
      self.ac_text = "Batt"
    
    index = string.find("%", apm[6])
    self.batt_px = float(apm[6][:index])

    #print self.batt_px

  ##################################################
  #
  def update(self):
    px = self.batt_px / 100.0
    if px > 1.0:  px = 1.0
    
    if self.cfg.options["ac"]:
      self.ac.set_text(self.ac_text)
    if self.cfg.options["label"]:
      self.label.set_text("%3.0f%%" % self.batt_px)
    if self.cfg.options["meter"]:
      self.progress.update(px)

  ##################################################
  #
  def destroy(self, *args):
    #mainquit()
    self.done = 1

######################################################################
#
def run(args):
  #print "run(%s)" % (args)
  cfg = config()
  cfg.load()
  
  bw = battwin(cfg)
  bw.run()


######################################################################
#
if __name__ == "__main__":
  import sys
  run(sys.argv[1:])
#else:
#  print "__name__ == %s" % __name__
